@@ -1679,3 +1679,33 @@ if(isFroxlorVersion('0.9.23-rc1'))
 	updateToVersion('0.9.23');
 }
 
+if(isFroxlorVersion('0.9.23'))
+{
+	showUpdateStep("Updating from 0.9.23 to 0.9.24-svn1");
+	lastStepStatus(0);
+
+	/* add new settings for logrotate - support */
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'logrotate_enabled', '0');");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'logrotate_binary', '/usr/sbin/logrotate');");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'logrotate_interval', 'weekly');");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'logrotate_keep', '4');");
+
+	updateToVersion('0.9.24-svn1');
+}
+
+if(isFroxlorVersion('0.9.24-svn1'))
+{
+	showUpdateStep("Updating from 0.9.24-svn1 to 0.9.24-rc1");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.24-rc1');
+}
+
+if(isFroxlorVersion('0.9.24-rc1'))
+{
+	showUpdateStep("Updating from 0.9.24-rc1 to 0.9.24");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.24');
+}
+
