@@ -80,7 +80,7 @@ while($row_database = $db->fetch_array($databases))
 			$databases_list[] = strtolower($databases_list_row['Database']);
 		}
 	}
-	
+
 	if(in_array(strtolower($row_database['databasename']), $databases_list))
 	{
 		$mysql_usage_result = $db_root->query("SHOW TABLE STATUS FROM `" . $db_root->escape($row_database['databasename']) . "`");
@@ -102,6 +102,11 @@ while($row_database = $db->fetch_array($databases))
 
 $db_root->close();
 
+# We are using the file-system quota, this will speed up the diskusage - collection
+if ($settings['system']['diskquota_enabled'])
+{
+	$usedquota = getFilesystemQuota();
+}
 
 $result = $db->query("SELECT * FROM `" . TABLE_PANEL_CUSTOMERS . "` ORDER BY `customerid` ASC");
 
@@ -179,7 +184,7 @@ while($row = $db->fetch_array($result))
 			safeSQLLogfile($domainlist[$row['customerid']], $row['loginname']);
 		}
 
-		// callAwstatsGetTraffic is called ONLY HERE and 
+		// callAwstatsGetTraffic is called ONLY HERE and
 		// *not* also in the special-logfiles-loop, because the function
 		// will iterate through all customer-domains and the awstats-configs
 		// know the logfile-name, #246
@@ -191,9 +196,38 @@ while($row = $db->fetch_array($result))
 		{
 			$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'], $row['documentroot'] . '/webalizer/', $caption, $domainlist[$row['customerid']]));
 		}
-		
+
 		// make the stuff readable for the customer, #258
 		makeChownWithNewStats($row);
+		
+		// logrotate
+		if($settings['system']['logrotate_enabled'] == '1')
+		{
+			fwrite($debugHandler, '   logrotate customers logs' . "\n");
+
+			$logrotatefile = '/tmp/froxlor_logrotate_tmpfile.conf';
+			$fh = fopen($logrotatefile, 'w');
+
+			$logconf = '# ' . basename($logrotatefile) . "\n" . '# Created ' . date('d.m.Y H:i') . "\n" .
+				$settings['system']['logfiles_directory'] . $row['loginname'] . '-access.log ' .
+				$settings['system']['logfiles_directory'] . $row['loginname'] . '-error.log {' . "\n" .
+				$settings['system']['logrotate_interval'] . "\n" .
+				'missingok' . "\n" .
+				'rotate ' . $settings['system']['logrotate_keep'] . "\n" .
+				'compress' . "\n" .
+				'delaycompress' . "\n" .
+				'notifempty' . "\n" .
+				'create' . "\n" .
+				'}' . "\n";
+
+			fwrite($fh, $logconf);
+			fclose($fh);
+
+			safe_exec(escapeshellcmd($settings['system']['logrotate_binary']) . ' ' . $logrotatefile);
+
+			fwrite($debugHandler, '   apache::reload: reloading apache' . "\n");
+			safe_exec(escapeshellcmd($settings['system']['apachereload_command']));
+		}
 
 		/**
 		 * Webalizer/AWStats might run for some time, so we'd better check if our database is still present
@@ -207,7 +241,7 @@ while($row = $db->fetch_array($result))
 			$db->close();
 			require_once ($pathtophpfiles . '/lib/userdata.inc.php');
 			$db = new db($sql['host'], $sql['user'], $sql['password'], $sql['db']);
-	
+
 			if ($db->link_id == 0) {
 				fclose($debugHandler);
 				unlink($lockfile);
@@ -285,23 +319,33 @@ while($row = $db->fetch_array($result))
 
 	fwrite($debugHandler, 'calculating webspace usage for ' . $row['loginname'] . "\n");
 	$webspaceusage = 0;
-	
-	if(file_exists($row['documentroot']) && is_dir($row['documentroot']))
+
+	# Using repquota, it's faster using this tool than using du traversing the complete directory
+	if ($settings['system']['diskquota_enabled'])
 	{
-		$back = safe_exec('du -sk ' . escapeshellarg($row['documentroot']) . '');
-		foreach($back as $backrow)
-		{
-			$webspaceusage = explode(' ', $backrow);
-		}
-	
-		$webspaceusage = floatval($webspaceusage['0']);
-		unset($back);
+		# We may use the array we created earlier, the used diskspace is stored in [<guid>][block][used]
+		$webspaceusage = floatval($usedquota[$row['guid']]['block']['used']);
 	}
 	else
 	{
-		fwrite($debugHandler, 'documentroot ' . $row['documentroot'] . ' does not exist' . "\n");
+		# Use the old fashioned way with "du"
+		if(file_exists($row['documentroot']) && is_dir($row['documentroot']))
+		{
+			$back = safe_exec('du -sk ' . escapeshellarg($row['documentroot']) . '');
+			foreach($back as $backrow)
+			{
+				$webspaceusage = explode(' ', $backrow);
+			}
+
+			$webspaceusage = floatval($webspaceusage['0']);
+			unset($back);
+		}
+		else
+		{
+			fwrite($debugHandler, 'documentroot ' . $row['documentroot'] . ' does not exist' . "\n");
+		}
 	}
-	
+
 	/**
 	 * MailSpace-Usage
 	 */
@@ -317,7 +361,7 @@ while($row = $db->fetch_array($result))
 		{
 			$emailusage = explode(' ', $backrow);
 		}
-	
+
 		$emailusage = floatval($emailusage['0']);
 		unset($back);
 	}
@@ -364,9 +408,8 @@ while($row = $db->fetch_array($result))
 	 * Total Usage
 	 */
 
-	$diskusage = floatval($webspaceusage + $emailusage + $mysqlusage);
-	if($settings['system']['backup_count'] == 0 && file_exists($row['documentroot'] . $settings['system']['backup_dir'])){
-		$backupsize = exec('du -s ' . escapeshellarg($row['documentroot'] . $settings['system']['backup_dir']) . '');
+	if($settings['system']['backup_count'] == 0 && file_exists($settings['system']['backup_dir'] . $row['loginname'])){
+		$backupsize = exec('du -s ' . escapeshellarg($settings['system']['backup_dir']) . $row['loginname'] . '');
                 $diskusage = floatval($webspaceusage + $emailusage + $mysqlusage - $backupsize);
         }
         else{
@@ -380,17 +423,17 @@ while($row = $db->fetch_array($result))
 	 */
 
 	$db->query("UPDATE `" . TABLE_FTP_QUOTATALLIES . "` SET `bytes_in_used`='" . (float)$current_diskspace['all'] . "'*1024 WHERE `name` = '" . $row['loginname'] . "' OR `name` LIKE '" . $row['loginname'] . $settings['customer']['ftpprefix'] . "%'");
-	
+
 	/**
 	 * Pureftpd Quota
 	 */
-	
+
 	if($settings['system']['ftpserver'] == "pureftpd")
 	{
 		$result_quota = $db->query("SELECT homedir FROM `" . TABLE_FTP_USERS . "` WHERE customerid = '" . $row['customerid'] . "'");
 
 	        // get correct user
-	        if($settings['system']['mod_fcgid'] == 1)
+	        if($settings['system']['mod_fcgid'] == 1 && $row['deactivated'] == '0')
 	        {
         	        $user = $row['loginname'];
 	                $group = $row['loginname'];
@@ -400,7 +443,7 @@ while($row = $db->fetch_array($result))
 	                $user = $row['guid'];
 	                $group = $row['guid'];
 	        }
-		
+
 		while($row_quota = $db->fetch_array($result_quota))
 		{
 			$quotafile = "" . $row_quota['homedir'] . ".ftpquota";
